pub struct RealTimeLinearTableLookup<T>where
T: RealNumber,{ /* private fields */ }Expand description
Allows to create a lookup table with linear interpolation between table points. This usually speeds up a convolution and sacrifices accuracy.
Implementations
Sourceimpl<T> RealTimeLinearTableLookup<T>where
T: RealNumber,
impl<T> RealTimeLinearTableLookup<T>where
T: RealNumber,
Sourceimpl RealTimeLinearTableLookup<f32>
impl RealTimeLinearTableLookup<f32>
Sourcepub fn from_raw_parts(table: &[f32], delta: f32, is_symmetric: bool) -> Self
pub fn from_raw_parts(table: &[f32], delta: f32, is_symmetric: bool) -> Self
Creates a lookup table by putting the pieces together.
Sourcepub fn from_conv_function(
other: &dyn RealImpulseResponse<f32>,
delta: f32,
len: usize,
) -> Self
pub fn from_conv_function( other: &dyn RealImpulseResponse<f32>, delta: f32, len: usize, ) -> Self
Creates a lookup table from another convolution function. The delta argument
can be used to balance performance vs. accuracy.
Sourceimpl RealTimeLinearTableLookup<f64>
impl RealTimeLinearTableLookup<f64>
Sourcepub fn from_raw_parts(table: &[f64], delta: f64, is_symmetric: bool) -> Self
pub fn from_raw_parts(table: &[f64], delta: f64, is_symmetric: bool) -> Self
Creates a lookup table by putting the pieces together.
Sourcepub fn from_conv_function(
other: &dyn RealImpulseResponse<f64>,
delta: f64,
len: usize,
) -> Self
pub fn from_conv_function( other: &dyn RealImpulseResponse<f64>, delta: f64, len: usize, ) -> Self
Creates a lookup table from another convolution function. The delta argument
can be used to balance performance vs. accuracy.
Sourceimpl RealTimeLinearTableLookup<f32>
impl RealTimeLinearTableLookup<f32>
Sourcepub fn to_complex(&self) -> ComplexTimeLinearTableLookup<f32>
pub fn to_complex(&self) -> ComplexTimeLinearTableLookup<f32>
Convert the lookup table into complex number space
Sourceimpl RealTimeLinearTableLookup<f64>
impl RealTimeLinearTableLookup<f64>
Sourcepub fn to_complex(&self) -> ComplexTimeLinearTableLookup<f64>
pub fn to_complex(&self) -> ComplexTimeLinearTableLookup<f64>
Convert the lookup table into complex number space
Sourceimpl RealTimeLinearTableLookup<f32>
impl RealTimeLinearTableLookup<f32>
Sourcepub fn fft(self) -> RealFrequencyLinearTableLookup<f32>
pub fn fft(self) -> RealFrequencyLinearTableLookup<f32>
Convert the lookup table into a magnitude spectrum
Sourceimpl RealTimeLinearTableLookup<f64>
impl RealTimeLinearTableLookup<f64>
Sourcepub fn fft(self) -> RealFrequencyLinearTableLookup<f64>
pub fn fft(self) -> RealFrequencyLinearTableLookup<f64>
Convert the lookup table into a magnitude spectrum