MapInplaceOps

Trait MapInplaceOps 

pub trait MapInplaceOps<T>: Sized
where T: Sized,
{ // Required method fn map_inplace<'a, A, F>(&mut self, argument: A, map: &F) where A: Sync + Copy + Send, F: Fn(T, usize, A) -> T + 'a + Sync; }
Operations which allow to iterate over the vector and to derive results or to change the vector.

Required Methods

fn map_inplace<'a, A, F>(&mut self, argument: A, map: &F)
where A: Sync + Copy + Send, F: Fn(T, usize, A) -> T + 'a + Sync,

Transforms all vector elements using the function map.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<S, T, N, D> MapInplaceOps<Complex<T>> for DspVec<S, T, N, D>

Source

impl<S, T, N, D> MapInplaceOps<T> for DspVec<S, T, N, D>
where S: ToSliceMut<T>, T: RealNumber, N: RealNumberSpace, D: Domain,