Trait basic_dsp_vector::ToSlice [−][src]
pub trait ToSlice<T> {
fn to_slice(&self) -> &[T];
fn len(&self) -> usize;
fn is_empty(&self) -> bool;
fn alloc_len(&self) -> usize;
fn try_resize(&mut self, len: usize) -> VoidResult;
}A trait to convert a type into a slice.
Required Methods
fn to_slice(&self) -> &[T]
Convert to a slice.
fn len(&self) -> usize
Length of a slice.
fn is_empty(&self) -> bool
Indicates whether or not this storage type is empty.
fn alloc_len(&self) -> usize
Gets the allocated length of a storage.
It's expected that self.alloc_len() >= self.len()
in all cases.
fn try_resize(&mut self, len: usize) -> VoidResult
Resizes the storage to support at least len elements or
returns an error if resizing isn't supported.
Implementations on Foreign Types
impl<'a, T> ToSlice<T> for &'a [T][src]
impl<'a, T> ToSlice<T> for &'a [T]impl<T> ToSlice<T> for [T][src]
impl<T> ToSlice<T> for [T]impl<'a, T> ToSlice<T> for &'a mut [T][src]
impl<'a, T> ToSlice<T> for &'a mut [T]impl<A: Array> ToSlice<A::Item> for ArrayVec<A> where
A::Item: RealNumber, [src]
impl<A: Array> ToSlice<A::Item> for ArrayVec<A> where
A::Item: RealNumber, impl<T> ToSlice<T> for Vec<T> where
T: RealNumber, [src]
impl<T> ToSlice<T> for Vec<T> where
T: RealNumber, impl<T> ToSlice<T> for Box<[T]>[src]
impl<T> ToSlice<T> for Box<[T]>