pub trait TrigOps {
// Required methods
fn sin(&mut self);
fn cos(&mut self);
fn tan(&mut self);
fn asin(&mut self);
fn acos(&mut self);
fn atan(&mut self);
fn sinh(&mut self);
fn cosh(&mut self);
fn tanh(&mut self);
fn asinh(&mut self);
fn acosh(&mut self);
fn atanh(&mut self);
}Expand description
Trigonometry methods.
Required Methods
Sourcefn sin(&mut self)
fn sin(&mut self)
Calculates the sine of each element in radians.
Example
use std::f32;
use basic_dsp_vector::*;
let mut vector = vec!(f32::consts::PI/2.0, -f32::consts::PI/2.0).to_real_time_vec();
vector.sin();
assert_eq!([1.0, -1.0], vector[..]);Sourcefn cos(&mut self)
fn cos(&mut self)
Calculates the cosine of each element in radians.
Example
use std::f32;
use basic_dsp_vector::*;
let mut vector = vec!(2.0 * f32::consts::PI, f32::consts::PI).to_real_time_vec();
vector.cos();
assert_eq!([1.0, -1.0], vector[..]);Sourcefn asin(&mut self)
fn asin(&mut self)
Calculates the principal value of the inverse sine of each element in radians.
Sourcefn acos(&mut self)
fn acos(&mut self)
Calculates the principal value of the inverse cosine of each element in radians.
Sourcefn atan(&mut self)
fn atan(&mut self)
Calculates the principal value of the inverse tangent of each element in radians.
Sourcefn asinh(&mut self)
fn asinh(&mut self)
Calculates the principal value of the inverse hyperbolic sine of each element in radians.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".